@@ -3,7 +3,7 @@
  * Kronolith_Driver:: defines an API for implementing storage backends
  * for Kronolith.
  *
- * $Horde: kronolith/lib/Driver.php,v 1.116.2.59 2007/03/15 18:59:55 jan Exp $
+ * $Horde: kronolith/lib/Driver.php,v 1.116.2.63 2007/05/02 22:01:09 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @since   Kronolith 0.1
@@ -412,7 +412,7 @@ class Kronolith_Event {
 
         if ($this->isAllDay()) {
             $vEvent->setAttribute('DTSTART', $this->start, array('VALUE' => 'DATE'));
-            $vEvent->setAttribute('DTEND', new Horde_Date($this->end->timestamp()-1), array('VALUE' => 'DATE'));
+            $vEvent->setAttribute('DTEND', new Horde_Date($this->end->timestamp()), array('VALUE' => 'DATE'));
         } else {
             $vEvent->setAttribute('DTSTART', $this->start);
             $vEvent->setAttribute('DTEND', $this->end);
@@ -734,7 +734,7 @@ class Kronolith_Event {
                 if (is_object($this->start)
                     && $this->start->hour == 0  && $this->start->min == 0
                     && $this->start->sec == 0
-                    && $this->end->hour == 23 && $this->end->sec == 59) {
+                    && $this->end->hour == 23 && $this->end->min == 59) {
                     $this->end = new Horde_Date(array(
                                    'year' => (int)$this->end->year,
                                    'month' => (int)$this->end->month,
@@ -745,7 +745,7 @@ class Kronolith_Event {
                 // Date field
                 $this->end = new Horde_Date(array('year' => (int)$end['year'],
                                                   'month' => (int)$end['month'],
-                                                  'mday' => (int)$end['mday'] + 1));
+                                                  'mday' => (int)$end['mday']));
                 $this->end->correct();
             }
         } else {
@@ -755,6 +755,11 @@ class Kronolith_Event {
             } else {
                 // End date equal to start date as per RFC 2445.
                 $this->end = Util::cloneObject($this->start);
+                if (is_array($start)) {
+                    // Date field
+                    $this->end->mday++;
+                    $this->end->correct();
+                }
             }
         }
 
@@ -1706,7 +1711,13 @@ class Kronolith_Event {
         }
 
         if ($this->isInitialized()) {
-            $dur_day_match = $this->end->mday - $this->start->mday;
+            require_once 'Date/Calc.php';
+            $dur_day_match = Date_Calc::dateDiff($this->start->mday,
+                                                 $this->start->month,
+                                                 $this->start->year,
+                                                 $this->end->mday,
+                                                 $this->end->month,
+                                                 $this->end->year);
             $dur_hour_match = $this->end->hour - $this->start->hour;
             $dur_min_match = $this->end->min - $this->start->min;
             while ($dur_min_match < 0) {
@@ -2111,7 +2122,7 @@ class Kronolith_Event {
         }
 
         if ($this->description) {
-            $tooltip .= "\n\n" . $this->description;
+            $tooltip .= "\n\n" . String::wrap($this->description);
         }
 
         return $tooltip;
